from __future__ import unicode_literals

from django.apps import AppConfig


class ApplicationConfig(AppConfig):
    name = "modeltranslation_rosetta"
    verbose_name = "Modeltranslaton rosetta"
